@@ -44,7 +44,7 @@ from ubuntuone.syncdaemon import (
     tritcask,
     volume_manager,
 )
-from ubuntu_sso.xdg_base_directory import (
+from dirspec.basedir import (
     xdg_cache_home,
     xdg_data_home,
 )
