@@ -164,20 +164,6 @@ class FakeActionQueue(object):
             verifyObject(interfaces.IActionQueue, self)
         return r
 
-    # IContentQueue
-    def cancel_download(self, share_id, node_id):
-        """Stub implementation."""
-
-    def cancel_upload(self, share_id, node_id):
-        """Stub implementation."""
-
-    def download(self, share_id, node_id, server_hash, path, fileobj_factory):
-        """Stub implementation."""
-
-    def upload(self, share_id, node_id, previous_hash, hash, crc32,
-               size, path, fileobj_factory):
-        """Stub implementation."""
-
     # IMetaQueue
     def connect(self, host=None, port=None, user_ssl=False):
         """Just send connect!."""
@@ -293,7 +279,6 @@ class FakeMain(main.Main):
         self.lr = local_rescan.LocalRescan(self.vm, self.fs,
                                            self.event_q, self.action_q)
 
-        self.eventlog_listener = None
         self.status_listener = FakeStatusListener()
 
     def _connect_aq(self, _):
