@@ -38,6 +38,7 @@ import dbus.service
 
 from twisted.internet.defer import Deferred, inlineCallbacks
 from ubuntuone.devtools.handlers import MementoHandler
+from ubuntuone.devtools.testcases import skipTest
 from ubuntuone.devtools.testcases.dbus import DBusTestCase
 
 from ubuntuone.platform.credentials import (
@@ -657,6 +658,7 @@ class SameAppWithErrorTestCase(SameAppNoErrorTestCase):
         args = ('CredentialsError', verify)
         super(SameAppWithErrorTestCase, self).connect_signals(callback=args)
 
+    @skipTest('Failing on Ubuntu 13.04 - bug #1085204')
     @inlineCallbacks
     def test_find_credentials_sync(self):
         """The find_credentials_sync method calls ubuntu_sso's method."""
