@@ -662,13 +662,13 @@ class TestWatch(BaseTwistedTestCase):
         self.assertTrue(self.invalid_path not in watch._subdirs)
 
 
-class TestWatchManager(BaseTwistedTestCase):
-    """Test the watch manager."""
+class TestWatchManagerStopping(BaseTwistedTestCase):
+    """Tests that stop the watch manager themselves."""
 
     @defer.inlineCallbacks
     def setUp(self):
         """Set each of the tests."""
-        yield super(TestWatchManager, self).setUp()
+        yield super(TestWatchManagerStopping, self).setUp()
         self.manager = WatchManager(None)
         self.fake_events_processor = FakeEventsProcessor()
 
@@ -686,31 +686,26 @@ class TestWatchManager(BaseTwistedTestCase):
         yield self.manager.stop()
         self.assertTrue(self.was_called, 'The watch stop should be called.')
 
-    def test_stop_multiple(self):
-        """Test that stop is fired when *all* watches have stopped."""
-        raise NotImplementedError
+
+class TestWatchManager(BaseTwistedTestCase):
+    """Test the watch manager."""
+
+    @defer.inlineCallbacks
+    def setUp(self):
+        """Set each of the tests."""
+        yield super(TestWatchManager, self).setUp()
+        self.manager = WatchManager(None)
+        self.addCleanup(self.manager.stop)
+        self.fake_events_processor = FakeEventsProcessor()
 
     def test_get_present_watch(self):
-        """Test that we can get a Watch using is wd."""
+        """Test that we can get a Watch using its wd."""
         self.assertEqual(self.watch, self.manager.get_watch(1))
 
     def test_get_missing_watch(self):
         """Test that we get an error when trying to get a missing wd."""
         self.assertRaises(KeyError, self.manager.get_watch, (1,))
 
-    def test_delete_present_watch(self):
-        """Test that we can remove a present watch."""
-        self.was_called = False
-
-        def stop_watching():
-            """Fake stop watch."""
-            self.was_called = True
-            return defer.succeed(True)
-
-        self.watch.stop_watching = stop_watching
-        yield self.manager.del_watch(1)
-        self.assertRaises(KeyError, self.manager.get_watch, (1,))
-
     def test_add_single_watch(self):
         """Test the addition of a new single watch."""
         self.was_called = False
@@ -727,12 +722,12 @@ class TestWatchManager(BaseTwistedTestCase):
         self.assertEqual(1, len(self.manager._wdm))
         self.assertTrue(self.was_called, 'The watch start was not called.')
 
-    def test_get_watch_present_wd(self):
-        """Test that the correct path is returned."""
+    def test_get_path_present_wd(self):
+        """Test the path for a present wd."""
         self.assertEqual(self.path + os.path.sep, self.manager.get_path(1))
 
-    def test_get_watch_missing_wd(self):
-        """Test that the correct path is returned."""
+    def test_get_path_missing_wd(self):
+        """Test returning None for a missing wd."""
         self.manager._wdm = {}
         self.assertEqual(None, self.manager.get_path(1))
 
@@ -751,13 +746,27 @@ class TestWatchManager(BaseTwistedTestCase):
 
     def test_rm_present_wd(self):
         """Test the removal of a present watch."""
+        self.stop_called = False
+
         def fake_stop_watching():
             """Fake stop watch."""
+            self.stop_called = True
             return defer.succeed(True)
 
-        self.patch(self.watch, "stop_watching", fake_stop_watching)
+        self.platform_rm_watch_wd = None
+
+        def fake_platform_rm_watch(wd):
+            """Fake platform_manager.rm_watch."""
+            self.platform_rm_watch_wd = wd
+
+        self.patch(self.manager, "stop_watching", fake_stop_watching)
+        self.patch(self.manager.platform_manager,
+                   "rm_watch", fake_platform_rm_watch)
+
         yield self.manager.rm_watch(1)
+        self.assertTrue(self.stop_called)
         self.assertEqual(None, self.manager._wdm.get(1))
+        self.assertEqual(self.platform_rm_watch_wd, 1)
 
     def test_rm_root_path(self):
         """Test the removal of a root path."""
@@ -800,14 +809,6 @@ class TestWatchManager(BaseTwistedTestCase):
         self.assertEqual(1, len(events))
 
 
-class TestWatchManagerAddWatches(BaseTwistedTestCase):
-    """Test the watch manager."""
-
-    def test_add_watch_twice(self):
-        """Adding a watch twice succeeds when the watch is running."""
-        raise NotImplementedError
-
-
 class FakeEvent(object):
     """Fake event."""
 
