@@ -70,6 +70,73 @@ class FakeTimer(object):
         self.callback = callback
 
 
+class FakeAppLaunchContext(object):
+    def set_timestamp(self, timestamp):
+        self.timestamp = timestamp
+
+
+class FakeGdkDisplay(object):
+    """Fake Gdk.Display"""
+    def get_app_launch_context(self):
+        return FakeAppLaunchContext()
+
+
+class FakeNullGdk(object):
+    """Fake Gdk.Display with no default"""
+    @staticmethod
+    def get_default():
+        return None
+
+
+class FakeAppInfo(object):
+    """Fake Gio.AppInfo"""
+    instance = None
+    name = ""
+    desktop_id = ""
+    command_line = ""
+    opened_uri = ""
+    launched = True
+    context = None
+    files = []
+    flags = 0
+
+    def __new__(cls, *args, **kwargs):
+        cls.instance = super(FakeAppInfo, cls).__new__(cls, *args, **kwargs)
+        return cls.instance
+
+    def __init__(self, command_line="", name="", flags=0):
+        self.command_line = command_line
+        self.name = name
+        self.flags = flags
+
+    @classmethod
+    def launch_default_for_uri(cls, uri, context):
+        cls.opened_uri = uri
+        cls.context = context
+
+    @classmethod
+    def create_from_commandline(cls, command_line, name, flags):
+        cls.instance.__init__(command_line, name, flags)
+        return cls.instance
+
+    def launch(self, files, context):
+        self.launched = True
+        self.files = files
+        self.context = context
+
+
+class FakeDesktopAppInfo(FakeAppInfo):
+    """Fake Gio.DestkopAppInfo"""
+    def __init__(self, desktop_id=""):
+        super(FakeDesktopAppInfo, self).__init__()
+        self.desktop_id = desktop_id
+
+    @classmethod
+    def new(cls, desktop_id):
+        cls.instance.__init__(desktop_id)
+        return cls.instance
+
+
 class FakeSyncdaemonService(object):
     """Fake SyncdaemonService."""
 
@@ -103,6 +170,7 @@ class FakeSyncMenuApp(object):
     @classmethod
     def clean(cls):
         """Clear the values stored in data."""
+        FakeSyncMenuApp.data = {}
 
     def set_menu(self, server):
         """Set the menu for SyncMenu App."""
@@ -141,6 +209,7 @@ class SyncMenuTestCase(TestCase):
     def setUp(self):
         yield super(SyncMenuTestCase, self).setUp()
         self.patch(linux.SyncMenu, "App", FakeSyncMenuApp)
+        self.patch(linux.Gdk.Display, "get_default", FakeGdkDisplay)
         FakeSyncMenuApp.clean()
         self.syncdaemon_service = FakeSyncdaemonService()
         self.status_frontend = FakeStatusFrontend()
@@ -186,54 +255,105 @@ class SyncMenuTestCase(TestCase):
         self.assertIsInstance(self.sync_menu.transfers.separator,
             linux.Dbusmenu.Menuitem)
 
+    def test_get_launch_context_with_display(self):
+        """Check that the proper context is returned."""
+        timestamp = time.time()
+        context = self.sync_menu._get_launch_context(timestamp)
+        self.assertEqual(timestamp, context.timestamp)
+
+    def test_get_launch_context_with_no_display(self):
+        """Check that the proper context is returned."""
+        self.patch(linux.Gdk, "Display", FakeNullGdk)
+        context = self.sync_menu._get_launch_context(time.time())
+        self.assertEqual(context, None)
+
+    def test_open_control_panel_by_command_line(self):
+        """Check that the proper action is executed."""
+        appinfo = FakeAppInfo()
+        self.patch(linux.Gio, "AppInfo", appinfo)
+        timestamp = time.time()
+        self.sync_menu._open_control_panel_by_command_line(timestamp)
+
+        self.assertEqual(appinfo.command_line, linux.CLIENT_COMMAND_LINE)
+        self.assertEqual(appinfo.context.timestamp, timestamp)
+
+    def test_open_control_panel_by_command_line_with_arg(self):
+        """Check that the proper action is executed."""
+        appinfo = FakeAppInfo()
+        self.patch(linux.Gio, "AppInfo", appinfo)
+        timestamp = time.time()
+        arg = "--test-arg"
+        self.sync_menu._open_control_panel_by_command_line(timestamp, arg)
+
+        self.assertEqual(appinfo.command_line, "%s %s" % (linux.CLIENT_COMMAND_LINE, arg))
+        self.assertEqual(appinfo.context.timestamp, timestamp)
+
+    def test_open_uri(self):
+        """Check that the proper action is executed."""
+        appinfo = FakeAppInfo()
+        self.patch(linux.Gio, "AppInfo", appinfo)
+        timestamp = time.time()
+
+        self.sync_menu._open_uri(linux.UBUNTUONE_LINK, timestamp)
+        self.assertEqual(appinfo.opened_uri, linux.UBUNTUONE_LINK)
+        self.assertEqual(appinfo.context.timestamp, timestamp)
+
     def test_open_u1(self):
         """Check that the proper action is executed."""
-        data = []
+        appinfo = FakeDesktopAppInfo()
+        timestamp = time.time()
+        self.patch(linux.Gio, "DesktopAppInfo", appinfo)
 
-        self.patch(linux.glib, "spawn_command_line_async", data.append)
-        self.sync_menu.open_control_panel()
-        self.assertEqual(data, ['ubuntuone-control-panel-qt'])
+        self.sync_menu.open_control_panel(timestamp=timestamp)
+        self.assertEqual(appinfo.desktop_id, linux.CLIENT_DESKTOP_ID)
+        self.assertTrue(appinfo.launched)
+        self.assertEqual(appinfo.files, [])
+        self.assertEqual(appinfo.context.timestamp, timestamp)
 
     def test_open_share_tab(self):
         """Check that the proper action is executed."""
+        timestamp = time.time()
         data = []
 
-        self.patch(linux.glib, "spawn_command_line_async", data.append)
-        self.sync_menu.open_share_file_tab()
-        self.assertEqual(data, [
-            'ubuntuone-control-panel-qt --switch-to share_links'])
+        self.patch(self.sync_menu, "_open_control_panel_by_command_line", lambda t, a: data.append((t, a)))
+        self.sync_menu.open_share_file_tab(timestamp=timestamp)
+        self.assertEqual(data, [(timestamp, "--switch-to share_links")])
 
     def test_go_to_web(self):
         """Check that the proper action is executed."""
+        timestamp = time.time()
         data = []
 
-        self.patch(linux.webbrowser, "open", data.append)
-        self.sync_menu.open_go_to_web()
-        self.assertEqual(data, [linux.DASHBOARD])
+        self.patch(self.sync_menu, "_open_uri", lambda u, t: data.append((t, u)))
+        self.sync_menu.open_go_to_web(timestamp=timestamp)
+        self.assertEqual(data, [(timestamp, linux.DASHBOARD)])
 
     def test_open_ubuntu_one_folder(self):
         """Check that the proper action is executed."""
+        timestamp = time.time()
         data = []
 
-        self.patch(linux.webbrowser, "open", data.append)
-        self.sync_menu.open_ubuntu_one_folder()
-        self.assertEqual(data, [self.syncdaemon_service.fake_root_path])
+        self.patch(self.sync_menu, "_open_uri", lambda u, t: data.append((t, u)))
+        self.sync_menu.open_ubuntu_one_folder(timestamp=timestamp)
+        self.assertEqual(data, [(timestamp, "file://" + self.syncdaemon_service.fake_root_path)])
 
     def test_get_help(self):
         """Check that the proper action is executed."""
+        timestamp = time.time()
         data = []
 
-        self.patch(linux.webbrowser, "open", data.append)
-        self.sync_menu.open_web_help()
-        self.assertEqual(data, [linux.HELP_LINK])
+        self.patch(self.sync_menu, "_open_uri", lambda u, t: data.append((t, u)))
+        self.sync_menu.open_web_help(timestamp=timestamp)
+        self.assertEqual(data, [(timestamp, linux.HELP_LINK)])
 
     def test_more_storage(self):
         """Check that the proper action is executed."""
+        timestamp = time.time()
         data = []
 
-        self.patch(linux.webbrowser, "open", data.append)
-        self.sync_menu.open_get_more_storage()
-        self.assertEqual(data, [linux.GET_STORAGE_LINK])
+        self.patch(self.sync_menu, "_open_uri", lambda u, t: data.append((t, u)))
+        self.sync_menu.open_get_more_storage(timestamp=timestamp)
+        self.assertEqual(data, [(timestamp, linux.GET_STORAGE_LINK)])
 
     def test_empty_transfers(self):
         """Check that the Transfers menu is empty."""
