@@ -35,6 +35,7 @@ from twisted.internet import defer, protocol, reactor
 from twisted.trial.unittest import TestCase
 from PyQt4.QtCore import QCoreApplication
 from PyQt4.QtNetwork import QAuthenticator
+from ubuntuone.devtools.testcases import skipIfOS
 from ubuntuone.devtools.testcases.squid import SquidTestCase
 
 from tests.proxy import (
@@ -507,6 +508,7 @@ class AnonProxyRemoteSocketTestCase(RemoteSocketTestCase):
         self.parse_headers(raw_headers)
 
 
+@skipIfOS('linux2', 'LP: #1111880 - ncsa_auth crashing for auth proxy tests.')
 class AuthenticatedProxyRemoteSocketTestCase(AnonProxyRemoteSocketTestCase):
     """Tests for the client going thru an authenticated proxy."""
 
