@@ -435,12 +435,6 @@ class TestConfigBasic(BaseTwistedTestCase):
         conf_1 = config._Config(conf_file)
         self.assertEquals(True, conf_1.get_show_all_notifications())
 
-    def test_load_branch_configuration(self):
-        """Check that the configuration from the branch is loaded."""
-        config_files = config.get_config_files()
-        rootdir = os.environ['ROOTDIR']
-        branch_config = os.path.join(rootdir, "data", config.CONFIG_FILE)
-        self.assertIn(branch_config, config_files)
 
     def test_get_simult_transfers(self):
         """Get simult transfers."""
@@ -516,7 +510,16 @@ class UnicodePathsTestCase(TestCase):
         branch_config = os.path.join(fake_path, config.CONFIG_FILE)
         self.assertIn(branch_config, config_files)
 
+    def test_load_branch_configuration(self):
+        """Check that the configuration from the branch is loaded."""
+        config_files = [os.path.normpath(p) for p in config.get_config_files()]
+        rootdir = os.environ['ROOTDIR']
+        branch_config = os.path.join(rootdir, "data", config.CONFIG_FILE)
+        branch_logging_config = os.path.join(rootdir, "data", config.CONFIG_LOGS)
+        self.assertIn(branch_config, config_files)
+        self.assertIn(branch_logging_config, config_files)  
 
+        
 class ConfigglueParsersTests(BaseTwistedTestCase):
     """Tests for our custom configglue parsers."""
 
