@@ -342,6 +342,35 @@ class DataFileTest(BaseTestCase):
             with contextlib.closing(fmap):
                 self.assertRaises(BadHeader, data_file.read, fmap, 0)
 
+    def test_write_after_read_after_write(self):
+        """write data after a write/read cycle."""
+        data1 = os.urandom(200)
+        data_file = self.file_class(self.base_dir)
+        init_pos = data_file.fd.tell()
+        tstamp_1, value_1_pos, value_1_sz = data_file.write(0, 'foo', data1)
+        header = header_struct.pack(tstamp_1, len('foo'), len(data1), 0)
+        crc32 = crc32_struct.pack(zlib.crc32(header + 'foo' + data1))
+        self.assertEqual(init_pos + len(crc32 + header) + len('foo'),
+                         value_1_pos)
+        init_pos_2 = value_1_pos + len(data1)
+        data2 = os.urandom(100)
+        tstamp_2, value_2_pos, value_2_sz = data_file.write(0, 'foo1', data2)
+        header = header_struct.pack(tstamp_2, len('foo1'), len(data2), 0)
+        crc32 = crc32_struct.pack(zlib.crc32(header + 'foo1' + data2))
+        self.assertEqual(init_pos_2 + len(crc32 + header) + len('foo1'),
+                         value_2_pos)
+        # now read the first value
+        value_1 = data_file[value_1_pos:value_1_pos + value_1_sz]
+        self.assertEqual(value_1, data1)
+        # now write something else, should end up at the end.
+        init_pos_3 = value_2_pos + len(data2)
+        data3 = os.urandom(100)
+        tstamp_3, value_3_pos, value_3_sz = data_file.write(0, 'foo2', data3)
+        header = header_struct.pack(tstamp_3, len('foo2'), len(data3), 0)
+        crc32 = crc32_struct.pack(zlib.crc32(header + 'foo2' + data3))
+        self.assertEqual(init_pos_3 + len(crc32 + header) + len('foo2'),
+                         value_3_pos)
+
 
 class TempDataFileTest(DataFileTest):
     """Tests for TempDataFile."""
@@ -596,6 +625,8 @@ class DeadDataFileTest(ImmutableDataFileTest):
         dead_file = self.create_dead_file()
         self.assertRaises(NotImplementedError, dead_file.write, '1')
 
+    test_write_after_read_after_write = test_write
+
     def test_read(self):
         """Test that read always fails with NotImplementedError."""
         dead_file = self.create_dead_file()
