@@ -1,6 +1,6 @@
 # -*- encoding: utf-8 -*-
 #
-# Copyright 2009-2012 Canonical Ltd.
+# Copyright 2009-2013 Canonical Ltd.
 #
 # This program is free software: you can redistribute it and/or modify it
 # under the terms of the GNU General Public License version 3, as published
@@ -46,10 +46,6 @@ from ubuntuone.platform import ipc
 from ubuntuone.platform import logger
 from ubuntuone.platform import os_helper
 
-# This imports needs to be here in order to be included in this namespace
-from ubuntuone.platform import credentials
-from ubuntuone.platform import tools
-
 
 def expand_user(path):
     """Fix Python expanduser for weird chars in windows."""
