@@ -369,6 +369,10 @@ class FileSystemClient(RemoteClient):
     def get_dirty_nodes(self):
         """Rerturn a list of dirty nodes."""
 
+    @remote
+    def search_files(self, pattern):
+        """Returns a list of the files that matches this pattern."""
+
 
 class SharesClient(RemoteClient, Referenceable):
     """A ipc interface to interact with shares."""
