@@ -190,7 +190,7 @@ class StatusEvent(object):
 class FilePublishingStatus(StatusEvent):
     """Files that are made public with a url."""
 
-    MESSAGE_ONE = Q_("A file was just made public at %(new_public_url)s")
+    MESSAGE_ONE = Q_("A share link was just created at %(new_public_url)s")
 
     WEIGHT = 50
 
@@ -203,15 +203,15 @@ class FilePublishingStatus(StatusEvent):
         no_of_files = len(events)
         gettext.dngettext(
             GETTEXT_PACKAGE,
-            "%(event_count)d file was just made public.",
-            "%(event_count)d files were just made public.",
+            "%(event_count)d file was just shared.",
+            "%(event_count)d files were just shared.",
             no_of_files) % {'event_count': no_of_files}
 
 
 class FileUnpublishingStatus(StatusEvent):
     """Files that have stopped being published."""
 
-    MESSAGE_ONE = Q_("A file is no longer published")
+    MESSAGE_ONE = Q_("A share link is no longer available")
     WEIGHT = 51
 
     def many(self, events):
@@ -219,8 +219,8 @@ class FileUnpublishingStatus(StatusEvent):
         no_of_files = len(events)
         gettext.dngettext(
             GETTEXT_PACKAGE,
-            "%(event_count)d file is no longer published.",
-            "%(event_count)d files are no longer published.",
+            "%(event_count)d file is no longer shared.",
+            "%(event_count)d files are no longer shared.",
             no_of_files) % {'event_count': no_of_files}
 
 
