@@ -37,7 +37,10 @@ import logging
 
 from twisted.internet import defer
 
-from ubuntuone.platform import access, FilesystemMonitor
+from ubuntuone.platform.os_helper import access
+from ubuntuone.platform.filesystem_notifications.monitor import (
+    FilesystemMonitor,
+)
 
 # these are our internal events, what is inserted into the whole system
 EVENTS = {
@@ -156,6 +159,7 @@ EVENTS = {
 
     'FSM_FILE_CONFLICT': ('old_name', 'new_name'),
     'FSM_DIR_CONFLICT': ('old_name', 'new_name'),
+    'FSM_PARTIAL_COMMITED': ('share_id', 'node_id'),
 
     'VM_UDF_SUBSCRIBED': ('udf',),
     'VM_UDF_SUBSCRIBE_ERROR': ('udf_id', 'error'),
@@ -182,13 +186,17 @@ DEFAULT_HANDLER = "handle_default"  # receives (event_name, **kwargs)
 class EventQueue(object):
     """Manages the events from different sources and distributes them."""
 
-    def __init__(self, fs, ignore_config=None):
+    def __init__(self, fs, ignore_config=None, monitor_class=None):
         self.listener_map = {}
 
         self.log = logging.getLogger('ubuntuone.SyncDaemon.EQ')
         self.fs = fs
 
-        self.monitor = FilesystemMonitor(self, fs, ignore_config)
+        if monitor_class is None:
+            # use the default class returned by platform
+            self.monitor = FilesystemMonitor(self, fs, ignore_config)
+        else:
+            self.monitor = monitor_class(self, fs, ignore_config)
 
         self.dispatching = False
         self.dispatch_queue = collections.deque()
