@@ -155,8 +155,8 @@ if "HAS_OOFFICE" in os.environ:
 
             while True:
                 cells = [
-                    self.rules.getCellByPosition(i, iter_line).getFormula()
-                    for i in xrange(line_length)]
+                    self.rules.getCellByPosition(x, iter_line).getFormula()
+                    for x in xrange(line_length)]
                 if not any(cells):
                     break
 
@@ -183,8 +183,8 @@ if "HAS_OOFFICE" in os.environ:
 
             while True:
                 cells = [
-                    self.invalid.getCellByPosition(i, iter_line).getFormula()
-                                            for i in xrange(line_length)]
+                    self.invalid.getCellByPosition(x, iter_line).getFormula()
+                                            for x in xrange(line_length)]
                 if not any(cells):
                     break
 
