@@ -364,7 +364,7 @@ class LocalRescan(object):
         """Resume an interrupted download."""
         mdobj = self.fsm.get_by_path(fullname)
         self.aq.download(mdobj.share_id, mdobj.node_id,
-                         mdobj.server_hash, fullname)
+                         mdobj.server_hash, mdobj.mdid)
 
     def _resume_upload(self, fullname):
         """Resume an interrupted upload."""
@@ -372,7 +372,7 @@ class LocalRescan(object):
         upload_id = getattr(mdobj, 'upload_id', None)
         self.aq.upload(mdobj.share_id, mdobj.node_id, mdobj.server_hash,
                        mdobj.local_hash, mdobj.crc32, mdobj.size,
-                       fullname, upload_id=upload_id)
+                       mdobj.mdid, upload_id=upload_id)
 
     def check_stat(self, fullname, oldstat):
         """Check stat info and return if different.
