@@ -48,7 +48,6 @@ from ubuntuone.syncdaemon import (
     volume_manager,
 )
 from ubuntuone import syncdaemon, clientdefs
-from ubuntuone.platform import event_logging
 from ubuntuone.syncdaemon import status_listener
 from ubuntuone.syncdaemon.interaction_interfaces import SyncdaemonService
 from ubuntuone.syncdaemon.states import StateManager, QueueManager
@@ -147,22 +146,12 @@ class Main(object):
         if user_config.get_autoconnect():
             self.external.connect(autoconnecting=True)
 
-        self.eventlog_listener = None
-        self.start_event_logger()
-
         self.status_listener = None
         self.start_status_listener()
 
         self.mark = task.LoopingCall(self.log_mark)
         self.mark.start(mark_interval)
 
-    def start_event_logger(self):
-        """Start the event logger if it's available for this platform."""
-        self.eventlog_listener = event_logging.get_listener(self.fs, self.vm)
-        # subscribe to EQ, to be unsubscribed in shutdown
-        if self.eventlog_listener:
-            self.event_q.subscribe(self.eventlog_listener)
-
     def start_status_listener(self):
         """Start the status listener if it is configured to start."""
         self.status_listener = status_listener.get_listener(self.fs, self.vm,
@@ -228,8 +217,6 @@ class Main(object):
         self.event_q.push('SYS_QUIT')
 
         self.event_q.unsubscribe(self.vm)
-        if getattr(self, 'eventlog_listener', None) is not None:
-            self.event_q.unsubscribe(self.eventlog_listener)
         if getattr(self, 'status_listener', None) is not None:
             self.event_q.unsubscribe(self.status_listener)
 
