@@ -36,6 +36,7 @@ from ubuntuone.syncdaemon import (
     config,
     RECENT_TRANSFERS,
     UPLOADING,
+    DOWNLOADING
 )
 from ubuntuone.syncdaemon.interaction_interfaces import (
     get_share_dict, get_udf_dict)
@@ -74,8 +75,11 @@ class StatusListener(object):
     def menu_data(self):
         """Return the info necessary to construct the sync menu."""
         uploading = self.status_frontend.files_uploading()
+        downloading = self.status_frontend.files_downloading()
         transfers = self.status_frontend.recent_transfers()
-        data = {RECENT_TRANSFERS: transfers, UPLOADING: uploading}
+        data = {RECENT_TRANSFERS: transfers,
+                UPLOADING: uploading,
+                DOWNLOADING: downloading}
         return data
 
     def get_show_all_notifications(self):
