@@ -49,6 +49,17 @@ from operator import attrgetter
 from collections import namedtuple
 from UserDict import DictMixin
 
+from ubuntuone.platform import (
+    is_dir,
+    listdir,
+    make_dir,
+    open_file,
+    path_exists,
+    remove_file,
+    rename,
+    stat_path,
+)
+
 
 crc32_fmt = '>i'
 crc32_size = struct.calcsize(crc32_fmt)
@@ -200,7 +211,7 @@ class DataFile(object):
 
     @property
     def size(self):
-        return os.stat(self.filename).st_size
+        return stat_path(self.filename).st_size
 
     @classmethod
     def _get_next_file_id(cls):
@@ -216,30 +227,30 @@ class DataFile(object):
     @property
     def has_hint(self):
         """Return true if there is a hint file on-disk."""
-        return os.path.exists(self.hint_filename)
+        return path_exists(self.hint_filename)
 
     @property
     def hint_size(self):
         """Return the hint file size."""
         if self.has_hint:
-            return os.stat(self.hint_filename).st_size
+            return stat_path(self.hint_filename).st_size
         return 0
 
     def exists(self):
-        return os.path.exists(self.filename)
+        return path_exists(self.filename)
 
     def make_immutable(self):
         """Make this data file immutable."""
         self.close()
         new_name = self.filename.replace(LIVE, INACTIVE)
-        os.rename(self.filename, new_name)
+        rename(self.filename, new_name)
         return ImmutableDataFile(*os.path.split(new_name))
 
     def _open(self):
-        if not os.path.exists(self.filename):
+        if not path_exists(self.filename):
             # create the file and open it for append
-            open(self.filename, 'wb').close()
-        self.fd = open(self.filename, 'a+b')
+            open_file(self.filename, 'wb').close()
+        self.fd = open_file(self.filename, 'a+b')
 
     def close(self):
         """Close the file descriptor"""
@@ -361,16 +372,16 @@ class ImmutableDataFile(DataFile):
         new_name = self.filename.replace(INACTIVE, DEAD)
         new_hint_name = self.hint_filename.replace(INACTIVE, DEAD)
         self.close()
-        os.rename(self.filename, new_name)
+        rename(self.filename, new_name)
         self.filename = new_name
         if self.has_hint:
-            os.rename(self.hint_filename, new_hint_name)
+            rename(self.hint_filename, new_hint_name)
             self.hint_filename = new_hint_name
         self._open()
         return self
 
     def _open(self):
-        self.fd = open(self.filename, 'rb')
+        self.fd = open_file(self.filename, 'rb')
         fmmap = mmap.mmap(self.fd.fileno(), 0, access=mmap.ACCESS_READ)
         self.fmmap = fmmap
 
@@ -410,9 +421,9 @@ class DeadDataFile(ImmutableDataFile):
 
     def delete(self):
         """Delete this file and the hint if exists."""
-        os.unlink(self.filename)
+        remove_file(self.filename)
         if self.has_hint:
-            os.unlink(self.hint_filename)
+            remove_file(self.hint_filename)
 
     # make all inherited methods to fail
     def _not_implemented(self, *args, **kwargs):
@@ -436,19 +447,19 @@ class TempDataFile(DataFile):
         """Make this data file immutable."""
         self.close()
         new_name = self.filename.replace(self.temp_name, INACTIVE)
-        os.rename(self.filename, new_name)
+        rename(self.filename, new_name)
         if self.has_hint:
             new_hint_name = self.hint_filename.replace(self.temp_name,
                 INACTIVE)
-            os.rename(self.hint_filename, new_hint_name)
+            rename(self.hint_filename, new_hint_name)
         return ImmutableDataFile(*os.path.split(new_name))
 
     def delete(self):
         """Delete this file and the hint if exists."""
         self.close()
-        os.unlink(self.filename)
+        remove_file(self.filename)
         if self.has_hint:
-            os.unlink(self.hint_filename)
+            remove_file(self.hint_filename)
 
 
 class HintFile(object):
@@ -458,13 +469,13 @@ class HintFile(object):
         """Create the instance."""
         self.path = path
         self.tempfile = None
-        if os.path.exists(self.path) and os.stat(self.path).st_size > 0:
+        if path_exists(self.path) and stat_path(self.path).st_size > 0:
             # if it's there and size > 0, open only for read
-            self.fd = open(self.path, 'rb')
+            self.fd = open_file(self.path, 'rb')
         else:
             # this is a new hint file, lets create it as a tempfile.
             self.tempfile = tempfile.mktemp(dir=os.path.dirname(self.path))
-            self.fd = open(self.tempfile, 'w+b')
+            self.fd = open_file(self.tempfile, 'w+b')
 
     def iter_entries(self):
         """Return a generator over the hint entries."""
@@ -508,7 +519,7 @@ class HintFile(object):
             self.fd.close()
         # if this is a new hint file, rename it to the real path.
         if self.tempfile:
-            os.rename(self.tempfile, self.path)
+            rename(self.tempfile, self.path)
 
 
 class Keydir(dict):
@@ -627,9 +638,9 @@ class Tritcask(object):
         self.dead_bytes_threshold = dead_bytes_threshold
         self.max_immutable_files = max_immutable_files
         self.auto_merge = auto_merge
-        if not os.path.exists(self.base_path):
-            os.makedirs(self.base_path)
-        elif not os.path.isdir(self.base_path):
+        if not path_exists(self.base_path):
+            make_dir(self.base_path, recursive=True)
+        elif not is_dir(self.base_path):
             raise ValueError('path must be a directory.')
         self.live_file = None
         self._immutable = {}
@@ -719,7 +730,7 @@ class Tritcask(object):
         base_path = self.base_path
         if not base_path.endswith(os.path.sep):
             base_path += os.path.sep
-        files = os.listdir(self.base_path)
+        files = listdir(self.base_path)
         for filename in files:
             # first check for hint and dead
             if is_hint(filename):
@@ -748,7 +759,7 @@ class Tritcask(object):
                 logger.warning("Failed to open %s, renaming it to: %s - "
                                "error: %s", orig, dest, e)
                 # rename it to "broken"
-                os.rename(orig, dest)
+                rename(orig, dest)
         # immutable files + live
         logger.info("found %s data files, %s dead and %s broken files",
                     len(self._immutable) + 1, dead_files, broken_files)
